@@ -166,7 +166,9 @@ enum {
     kGART_2xRESET		= 0x00010000,
     kGART_DIS_SBA_DET		= 0x00020000,
     kGART_SYNC_MODE		= 0x00040000,
-    kGART_PERF_RD		= 0x00080000
+    kGART_PERF_RD		= 0x00080000,
+    kGART_B2B_GNT		= 0x00200000,
+    kGART_FAST_DDR		= 0x00400000
 };
 
 
@@ -182,7 +184,7 @@ class IORangeAllocator;
 
 class AppleMacRiscAGP : public AppleMacRiscPCI
 {
-    OSDeclareDefaultStructors(AppleMacRiscAGP)
+    OSDeclareDefaultStructors(AppleMacRiscAGP);
 
 protected:
     IORangeAllocator *	agpRange;
@@ -198,13 +200,17 @@ protected:
     UInt8		isU3;
     UInt8		isU32;
     IOBufferMemoryDescriptor * dummyPage;
+    addr64_t		dummyPhys;
+    OSData *		gartHandle;	// Handle returned by IOMapper
 
 private:
     virtual IOReturn setAGPEnable( IOAGPDevice * master, bool enable,
 					IOOptionBits options = 0 );
 
-public:
+    inline void configSetClearMask( IOPCIAddressSpace space,
+					  UInt8 offset, UInt32 data, UInt32 mask );
 
+public:
     virtual bool configure( IOService * provider );
 
     virtual IOPCIDevice * createNub( OSDictionary * from );
@@ -241,6 +247,7 @@ public:
 				       IOMemoryDescriptor * memory,
 				       IOByteCount agpOffset,
 				       IOOptionBits options = 0 );
+
 };
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
